@@ -92,6 +92,27 @@ class TestEval(unittest.TestCase):
         eval = tfkit.utility.eval_metric.EvalMetric(tokenizer, normalize_text=True)
         self.assertEqual(eval.tokenize_text("How's this work"), "how ' s this work")
 
+    @pytest.mark.skip()
+    def testNLGWithPAD(self):
+        tokenizer = BertTokenizer.from_pretrained('voidful/albert_chinese_tiny')
+
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
+        eval.add_record("input", "a b", "a b ///a c c", task='default')
+        eval.add_record("input", "d c", "a b c///a c c///d c", task='default')
+        for s in eval.cal_score('nlg'):
+            s1 = s[1]
+            print(s1)
+
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
+        eval.add_record("input", "a b", "a b ///a c c", task='nlg')
+        eval.add_record("input", "d c", "a b c///a c c///d c", task='nlg')
+        for s in eval.cal_score('nlg'):
+            s2 = s[1]
+            print(s2)
+
+        self.assertEqual(s1, s2)
+        self.assertAlmostEqual(s2['Bleu_1'], 1)
+
     @pytest.mark.skip()
     def testNLG(self):
         tokenizer = BertTokenizer.from_pretrained('voidful/albert_chinese_tiny')
@@ -102,13 +123,13 @@ class TestEval(unittest.TestCase):
             self.assertAlmostEqual(s[1]['Bleu_1'], 1)
             print(s)
 
-        eval1 = tfkit.utility.eval_metric.EvalMetric(tokenizer, max_candidate=1)
+        eval1 = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval1.add_record("input", "abc", " abc ", task='default')
         for s1 in eval1.cal_score('nlg'):
             self.assertAlmostEqual(s1[1]['Bleu_1'], 1)
             print(s1)
 
-        eval1 = tfkit.utility.eval_metric.EvalMetric(tokenizer, max_candidate=1)
+        eval1 = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval1.add_record("input", "abb", " abc ", task='default')
         eval1.add_record("input", "abc", " abc ", task='default')
         eval1.add_record("input", "abd", " abc ", task='default')
@@ -116,32 +137,32 @@ class TestEval(unittest.TestCase):
             self.assertAlmostEqual(s1[1]['Bleu_1'], 0.3333333)
             print(s1)
 
-        eval3 = tfkit.utility.eval_metric.EvalMetric(tokenizer, max_candidate=3)
+        eval3 = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval3.add_record("input", "abc ", "abb ///acc/// abc ", task='default')
         for s3 in eval3.cal_score('nlg'):
             self.assertAlmostEqual(s3[1]['Bleu_1'], 1)
             print(s3)
 
-        eval6 = tfkit.utility.eval_metric.EvalMetric(tokenizer, max_candidate=6)
+        eval6 = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval6.add_record("input", "abc", "abb /// acc ///abc", task='default')
         for s6 in eval6.cal_score('nlg'):
             self.assertAlmostEqual(s6[1]['Bleu_1'], 1)
             print(s6)
         self.assertTrue(s1[0] == s3[0] == s6[0])
 
-        eval1 = tfkit.utility.eval_metric.EvalMetric(tokenizer, max_candidate=1)
+        eval1 = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval1.add_record("input", "opq", "abc", task='default')
         for s1 in eval1.cal_score('nlg'):
             self.assertAlmostEqual(s1[1]['Bleu_1'], 0)
             print(s1)
 
-        eval3 = tfkit.utility.eval_metric.EvalMetric(tokenizer, max_candidate=3)
+        eval3 = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval3.add_record("input", "opq", "abb///acc///abc", task='default')
         for s3 in eval3.cal_score('nlg'):
             self.assertAlmostEqual(s3[1]['Bleu_1'], 0)
             print(s3)
 
-        eval6 = tfkit.utility.eval_metric.EvalMetric(tokenizer, max_candidate=6)
+        eval6 = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval6.add_record("input", "opq", "abb /// acc///abc", task='default')
         for s6 in eval6.cal_score('nlg'):
             self.assertAlmostEqual(s6[1]['Bleu_1'], 0)
